@@ -10,7 +10,7 @@ import shutil
 import tarfile
 import tempfile
 
-from hashlib import sha1
+from hashlib import sha256
 
 import psys
 
@@ -109,7 +109,7 @@ class CompressedTarFile:
             self.__temp_file = tempfile.NamedTemporaryFile(dir = "/var/tmp")
             shutil.copyfileobj(compressed_file, self.__temp_file)
             self.__temp_file.flush()
-        except BaseException as e:
+        except BaseException as error:
             if self.__temp_file is not None:
                 try:
                     self.__temp_file.close()
@@ -119,10 +119,10 @@ class CompressedTarFile:
                 finally:
                     self.__temp_file = None
 
-            if not isinstance(e, Exception):
+            if not isinstance(error, Exception):
                 raise
 
-            LOG.error("Failed to decompress '%s': %s.", path, psys.e(e))
+            LOG.error("Failed to decompress '%s': %s.", path, psys.e(error))
         else:
             LOG.debug("Decompressing finished.")
             self.__file = tarfile.open(self.__temp_file.name)
@@ -134,7 +134,7 @@ class HashableFile():
 
     def __init__(self, file):
         self.__file = file
-        self.__hash = sha1()
+        self.__hash = sha256()
 
 
     def hexdigest(self):
@@ -155,7 +155,7 @@ class HashableFile():
         """Resets the file position."""
 
         self.__file.seek(0)
-        self.__hash = sha1()
+        self.__hash = sha256()
 
 
 
